# Flask Skeleton
Basic flask app scaffolding.

Includes a basic app structure and templates.

## Install with pip
`pip install flask-skeleton`

## Run from the command line
`$ create-flask-app [Options] APPNAME`

Run `$ create-flask-app --help` for usage.

## Setup
1. `cd` into the app directory
2. Activate virtual environment: `$ source env/bin/activate`
3. Run tests: `$ python -m unittest`
4. Create database: `$ flask create-db`
5. Run: `$ flask run`

Source: [Flask Skeleton](https://github.com/enwawerueli/flask-skeleton).

Happy coding!
